package org.fuseri.modulelanguageschool.config;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.http.HttpMethod;
import org.springframework.security.config.annotation.web.builders.HttpSecurity;
import org.springframework.security.config.annotation.web.configuration.EnableWebSecurity;
import org.springframework.security.config.annotation.web.configurers.oauth2.server.resource.OAuth2ResourceServerConfigurer;
import org.springframework.security.web.SecurityFilterChain;
import org.springframework.web.servlet.config.annotation.EnableWebMvc;

@Configuration
@EnableWebSecurity
@EnableWebMvc


public class AppSecurityConfig {

    @Bean
    public SecurityFilterChain filterChain(HttpSecurity httpSecurity) throws Exception {
        httpSecurity.csrf().disable();
        httpSecurity.authorizeHttpRequests(x -> x
                .requestMatchers("/swagger-ui/**", "/v3/api-docs/**","/users/register").permitAll()

                .requestMatchers(HttpMethod.POST, "/courses/**").hasAuthority("SCOPE_test_1")
                .requestMatchers(HttpMethod.DELETE, "/courses/**").hasAuthority("SCOPE_test_1")
                .requestMatchers(HttpMethod.PUT, "/courses/**").hasAnyAuthority("SCOPE_test_1","SCOPE_test_2")
                .requestMatchers(HttpMethod.GET, "/courses/**").hasAnyAuthority("SCOPE_test_1", "SCOPE_test_2")


                .requestMatchers(HttpMethod.POST, "/lectures/**").hasAnyAuthority("SCOPE_test_1", "SCOPE_test_2")
                .requestMatchers(HttpMethod.DELETE, "/lectures/**").hasAnyAuthority("SCOPE_test_1", "SCOPE_test_2")
                .requestMatchers(HttpMethod.PUT, "/lectures/**").hasAnyAuthority("SCOPE_test_1","SCOPE_test_2")
                .requestMatchers(HttpMethod.GET, "/lectures/**").hasAnyAuthority("SCOPE_test_1", "SCOPE_test_2")


                .requestMatchers(HttpMethod.POST, "/users/**").hasAuthority("SCOPE_test_1")
                .requestMatchers(HttpMethod.DELETE, "/users/**").hasAuthority("SCOPE_test_1")
                .anyRequest().authenticated()
        ).oauth2ResourceServer(OAuth2ResourceServerConfigurer::opaqueToken)
        ;
        return httpSecurity.build();
    }
}
